@@ -1,4 +1,4 @@
-# Copyright 2009, 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2013, 2014 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -16,8 +16,7 @@
 
 """Tools for handling ReStructured Text."""
 
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import print_function, unicode_literals, absolute_import, division
 import docutils.io
 import docutils.core
 
